exceptiontools.ImpreciseTempoError
==================================

.. abjad-lineage:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError

.. autoclass:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__delattr__
      ~abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__getitem__
      ~abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__getslice__
      ~abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__repr__
      ~abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__setattr__
      ~abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__str__
      ~abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__unicode__

Bases
-----

- :py:class:`exceptions.Exception <exceptions.Exception>`

- :py:class:`exceptions.BaseException <exceptions.BaseException>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__unicode__
   :noindex:
